﻿using System;

using UIKit;
using Xuni.iOS.FlexChart;
using Xuni.iOS.ChartCore;
using Xuni.iOS.Core;
using Foundation;
namespace XuniiOSExample
{
	public partial class ViewController : UIViewController
	{
		private FlexChart chart;
		private XuniChartRectangleAnnotation rectAnno;
		public ViewController (IntPtr handle) : base (handle)
		{
		}

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();

			chart = new FlexChart();

			// set title/footer
			chart.Header = (NSString)"FlexChart Sales";
			chart.Footer = (NSString)"GrapeCity Xuni";
			chart.Legend.BorderWidth = 1;
			chart.Legend.BorderColor = UIColor.Gray;

			// set palette
			chart.Palette = XuniPalettes.Coral();
			// set data source
			NSMutableArray chartData = SalesData.GetSalesDataList();
			chart.ItemsSource = chartData;
			// bind X axis to display category names
			chart.BindingX = "Date";
			chart.Legend.Position = Position.PositionNone;
			// configure default axes
			chart.AxisX.LabelAngle = 45;
			chart.AxisX.Format = "d";
			chart.AxisY.Format = "c0";
			chart.AxisY.Title = "Dollars";

			// add second Y axis
			Axis y2 = new Axis(Position.PositionRight, chart);
			y2.MajorGridVisible = false;
			y2.MinorGridVisible = false;
			y2.LabelsVisible = true;
			y2.Title = "Downloads";
			chart.AxesArray.Add(y2);

			// create series with binding
			Series sales = new Series(chart, (NSString)"Sales", (NSString)"Sales"); 
			Series expenses = new Series(chart, (NSString)"Expenses", (NSString)"Expenses");
			Series downloads = new Series(chart, (NSString)"Downloads", (NSString)"Downloads");
			downloads.AxisY = y2;
			downloads.ChartType = ChartType.ChartTypeLine;
			chart.Series.Add(sales);
			chart.Series.Add(expenses);
			chart.Series.Add(downloads);

			rectAnno = new XuniChartRectangleAnnotation(chart);
			rectAnno.Attachment= XuniChartAnnotationAttachment.XuniChartAnnotationAttachmentAbsolute;
			rectAnno.Point = new XuniPoint(100, 75);

			rectAnno.Width = 100;
			rectAnno.Height = 100;
			rectAnno.Text = (NSString)"Tap the chart";


			rectAnno.TextColor = UIColor.Black;
			rectAnno.Font = UIFont.SystemFontOfSize (10);
			rectAnno.BorderWidth = 2;
			rectAnno.BorderColor = UIColor.FromRGBA(224, 224, 224, 204);
			rectAnno.Color = UIColor.FromRGBA(119, 204, 204, 204);
			chart.Annotations.Add (rectAnno);

			chart.Tapped += chart_tapped;


			chart.Tooltip.IsVisible = false;

			// configure animation
			chart.LoadAnimation.AnimationMode = AnimationMode.AnimationModePoint;
			View.AddSubview(chart);
		}

		public override void DidReceiveMemoryWarning ()
		{
			base.DidReceiveMemoryWarning ();
			// Release any cached data, images, etc that aren't in use.
		}
		public override void ViewDidLayoutSubviews()
		{
			base.ViewDidLayoutSubviews();
			//FlexChart g = (FlexChart)View.ViewWithTag(1);
			chart.Frame = new CoreGraphics.CGRect(0, 44, View.Bounds.Width, View.Bounds.Height - 44);
		}
		private bool chart_tapped(FlexChart sender, XuniPoint point)
		{
			bool result = false;
			XuniChartHitTestInfo hitTest = chart.HitTest(point);
			chart.PointToData (point);
			if (hitTest.DataPoint != null) {
				rectAnno.Text = "Series: " + hitTest.DataPoint.SeriesName + "\n" + "Value: $" + Math.Round(hitTest.DataPoint.Value);

			}
			return result;
		}
	}

}

